@@ -12,21 +12,19 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-import time
 import logging
-import warnings
-from collections.abc import Iterable
 import multiprocessing as mp
+import time
+import warnings
+
+from collections.abc import Iterable
+
 import numpy as np
 
-from .smc import SMC
-from ..model import modelcontext
-from ..backends.base import MultiTrace
-from ..parallel_sampling import _cpu_count
-
-EXPERIMENTAL_WARNING = (
-    "Warning: SMC-ABC is an experimental step method and not yet recommended for use in PyMC3!"
-)
+from pymc3.backends.base import MultiTrace
+from pymc3.model import modelcontext
+from pymc3.parallel_sampling import _cpu_count
+from pymc3.smc.smc import SMC
 
 
 def sample_smc(
@@ -35,9 +33,10 @@ def sample_smc(
     n_steps=25,
     start=None,
     tune_steps=True,
-    p_acc_rate=0.99,
+    p_acc_rate=0.85,
     threshold=0.5,
     save_sim_data=False,
+    save_log_pseudolikelihood=True,
     model=None,
     random_seed=-1,
     parallel=False,
@@ -45,36 +44,40 @@ def sample_smc(
     cores=None,
 ):
     r"""
-    Sequential Monte Carlo based sampling
+    Sequential Monte Carlo based sampling.
 
     Parameters
     ----------
     draws: int
         The number of samples to draw from the posterior (i.e. last stage). And also the number of
-        independent chains. Defaults to 1000.
+        independent chains. Defaults to 2000.
     kernel: str
         Kernel method for the SMC sampler. Available option are ``metropolis`` (default) and `ABC`.
-        Use `ABC` for likelihood free inference togheter with a ``pm.Simulator``.
+        Use `ABC` for likelihood free inference together with a ``pm.Simulator``.
     n_steps: int
         The number of steps of each Markov Chain. If ``tune_steps == True`` ``n_steps`` will be used
         for the first stage and for the others it will be determined automatically based on the
         acceptance rate and `p_acc_rate`, the max number of steps is ``n_steps``.
     start: dict, or array of dict
         Starting point in parameter space. It should be a list of dict with length `chains`.
-        When None (default) the starting point is sampled from the prior distribution. 
+        When None (default) the starting point is sampled from the prior distribution.
     tune_steps: bool
         Whether to compute the number of steps automatically or not. Defaults to True
     p_acc_rate: float
         Used to compute ``n_steps`` when ``tune_steps == True``. The higher the value of
-        ``p_acc_rate`` the higher the number of steps computed automatically. Defaults to 0.99.
+        ``p_acc_rate`` the higher the number of steps computed automatically. Defaults to 0.85.
         It should be between 0 and 1.
     threshold: float
         Determines the change of beta from stage to stage, i.e.indirectly the number of stages,
         the higher the value of `threshold` the higher the number of stages. Defaults to 0.5.
         It should be between 0 and 1.
     save_sim_data : bool
-        Whether or not to save the simulated data. This parameters only work with the ABC kernel.
-        The stored data corresponds to the posterior predictive distribution.
+        Whether or not to save the simulated data. This parameter only works with the ABC kernel.
+        The stored data corresponds to a samples from the posterior predictive distribution.
+    save_log_pseudolikelihood : bool
+        Whether or not to save the log pseudolikelihood values. This parameter only works with the
+        ABC kernel. The stored data can be used to compute LOO or WAIC values. Computing LOO/WAIC
+        values from log pseudolikelihood values is experimental.
     model: Model (optional if in ``with`` context)).
     random_seed: int
         random seed
@@ -105,17 +108,18 @@ def sample_smc(
 
      1. Initialize :math:`\beta` at zero and stage at zero.
      2. Generate N samples :math:`S_{\beta}` from the prior (because when :math `\beta = 0` the
-         tempered posterior is the prior).
+        tempered posterior is the prior).
      3. Increase :math:`\beta` in order to make the effective sample size equals some predefined
         value (we use :math:`Nt`, where :math:`t` is 0.5 by default).
      4. Compute a set of N importance weights W. The weights are computed as the ratio of the
         likelihoods of a sample at stage i+1 and stage i.
      5. Obtain :math:`S_{w}` by re-sampling according to W.
-     6. Use W to compute the covariance for the proposal distribution.
-     7. For stages other than 0 use the acceptance rate from the previous stage to estimate the
-        scaling of the proposal distribution and `n_steps`.
-     8. Run N Metropolis chains (each one of length `n_steps`), starting each one from a different
-        sample in :math:`S_{w}`.
+     6. Use W to compute the mean and covariance for the proposal distribution, a MVNormal.
+     7. For stages other than 0 use the acceptance rate from the previous stage to estimate
+        `n_steps`.
+     8. Run N independent Metropolis-Hastings (IMH) chains (each one of length `n_steps`),
+        starting each one from a different sample in :math:`S_{w}`. Samples are IMH as the proposal
+        mean is the of the previous posterior stage and not the current point in parameter space.
      9. Repeat from step 3 until :math:`\beta \ge 1`.
      10. The final result is a collection of N samples from the posterior.
 
@@ -133,11 +137,15 @@ def sample_smc(
         816-832. `link <http://ascelibrary.org/doi/abs/10.1061/%28ASCE%290733-9399
         %282007%29133:7%28816%29>`__
     """
-
     _log = logging.getLogger("pymc3")
     _log.info("Initializing SMC sampler...")
 
     model = modelcontext(model)
+    if model.name:
+        raise NotImplementedError(
+            "The SMC implementation currently does not support named models. "
+            "See https://github.com/pymc-devs/pymc3/pull/4365."
+        )
     if cores is None:
         cores = _cpu_count()
 
@@ -147,10 +155,8 @@ def sample_smc(
         cores = 1
 
     _log.info(
-        (
-            f"Multiprocess sampling ({chains} chain{'s' if chains > 1 else ''} "
-            f"in {cores} job{'s' if cores > 1 else ''})"
-        )
+        f"Sampling {chains} chain{'s' if chains > 1 else ''} "
+        f"in {cores} job{'s' if cores > 1 else ''}"
     )
 
     if random_seed == -1:
@@ -165,7 +171,6 @@ def sample_smc(
         raise TypeError("Invalid value for `random_seed`. Must be tuple, list or int")
 
     if kernel.lower() == "abc":
-        warnings.warn(EXPERIMENTAL_WARNING)
         if len(model.observed_RVs) != 1:
             warnings.warn("SMC-ABC only works properly with models with one observed variable")
         if model.potentials:
@@ -180,6 +185,7 @@ def sample_smc(
         p_acc_rate,
         threshold,
         save_sim_data,
+        save_log_pseudolikelihood,
         model,
     )
 
@@ -196,17 +202,26 @@ def sample_smc(
     else:
         results = []
         for i in range(chains):
-            results.append((sample_smc_int(*params, random_seed[i], i, _log)))
+            results.append(sample_smc_int(*params, random_seed[i], i, _log))
 
-    traces, sim_data, log_marginal_likelihoods, betas, accept_ratios, nsteps = zip(*results)
+    (
+        traces,
+        sim_data,
+        log_marginal_likelihoods,
+        log_pseudolikelihood,
+        betas,
+        accept_ratios,
+        nsteps,
+    ) = zip(*results)
     trace = MultiTrace(traces)
     trace.report._n_draws = draws
     trace.report._n_tune = 0
-    trace.report._t_sampling = time.time() - t1
     trace.report.log_marginal_likelihood = np.array(log_marginal_likelihoods)
+    trace.report.log_pseudolikelihood = log_pseudolikelihood
     trace.report.betas = betas
     trace.report.accept_ratios = accept_ratios
     trace.report.nsteps = nsteps
+    trace.report._t_sampling = time.time() - t1
 
     if save_sim_data:
         return trace, {modelcontext(model).observed_RVs[0].name: np.array(sim_data)}
@@ -223,12 +238,13 @@ def sample_smc_int(
     p_acc_rate,
     threshold,
     save_sim_data,
+    save_log_pseudolikelihood,
     model,
     random_seed,
     chain,
     _log,
 ):
-
+    """Run one SMC instance."""
     smc = SMC(
         draws=draws,
         kernel=kernel,
@@ -238,6 +254,7 @@ def sample_smc_int(
         p_acc_rate=p_acc_rate,
         threshold=threshold,
         save_sim_data=save_sim_data,
+        save_log_pseudolikelihood=save_log_pseudolikelihood,
         model=model,
         random_seed=random_seed,
         chain=chain,
@@ -267,6 +284,7 @@ def sample_smc_int(
         smc.posterior_to_trace(),
         smc.sim_data,
         smc.log_marginal_likelihood,
+        smc.log_pseudolikelihood,
         betas,
         accept_ratios,
         nsteps,
